import 'package:flutter/material.dart';
import 'package:provider/provider.dart';

import '../provider/data.dart';
import '../utils/get_images_list.dart';

class Home extends StatelessWidget {
  static const String id = 'home';

  Future<void> resetGame(Data myProvider) async {
    myProvider.updateImage = '';
  }

  Future<void> getImagesList(Data myProvider) async {
    GetImagesList getImagesList;
    getImagesList = GetImagesList();
    await getImagesList.init();
    if (getImagesList.images != null) {
      myProvider.updateImages = getImagesList.images;
    }
  }

  Container _buildImageSelectorItem(Data myProvider, String image) {
    double imageSize = 200;
    String imageAsset = 'assets/images/'+image+'.png';

    return Container(
      child: FlatButton(
        child: Container(
          decoration: BoxDecoration(
            borderRadius: BorderRadius.circular(8),
            border: Border.all(
              color: Colors.blue[200],
              width: 8,
            ),
          ),
          margin: EdgeInsets.all(2),
          child: Image(
            image: AssetImage(imageAsset),
            width: imageSize,
            height: imageSize,
            fit: BoxFit.fill
          ),
        ),
        onPressed: () {
          myProvider.updateImage = image;
        },
      ),
    );
  }

  Container _buildImageSelector(Data myProvider) {
    if (myProvider.images.length == 0) {
      getImagesList(myProvider);
    }
    List images = myProvider.images;

    return Container(
      padding: EdgeInsets.all(5),
      child: ListView(
        children: [
          for (var image in images)
            _buildImageSelectorItem(myProvider, image),
        ],
      ),
    );
  }

  Container _buildGameWidget(Data myProvider) {
    double imageSize = 250;
    String imageAsset = 'assets/images/'+myProvider.image+'.png';

    return Container(
      child: Column(
        mainAxisSize: MainAxisSize.min,
        mainAxisAlignment: MainAxisAlignment.center,
        children: [
          Container(
            margin: EdgeInsets.all(4),
            padding: EdgeInsets.all(4),
            decoration: BoxDecoration(
              color: Colors.blue,
              borderRadius: BorderRadius.circular(4),
              border: Border.all(
                color: Colors.green,
                width: 4,
              ),
            ),
            child: Image(
              image: AssetImage(imageAsset),
              width: imageSize,
              height: imageSize,
              fit: BoxFit.fill
            ),
          ),
        ],
      ),
    );
  }

  @override
  Widget build(BuildContext context) {
    Data _myProvider = Provider.of<Data>(context);

    return Scaffold(
      appBar: AppBar(
        title: Text('Puzzle'),
        actions: <Widget>[
          _myProvider.image == ''
          ? Text('')
          : IconButton(
            icon: const Icon(Icons.arrow_left_outlined),
            onPressed: () => resetGame(_myProvider),
          ),
        ],
      ),
      body: SafeArea(
        child: Center(
          child: _myProvider.image == ''
            ? _buildImageSelector(_myProvider)
            : _buildGameWidget(_myProvider),
        ),
      )
    );
  }
}
